package com.zanxiang.manage.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.manage.domain.dto.PayApplicationDTO;
import com.zanxiang.manage.domain.params.PayApplicationAddUpdateParam;
import com.zanxiang.manage.domain.params.PayApplicationListParam;
import com.zanxiang.manage.domain.vo.PayApplicationChoiceVO;
import com.zanxiang.manage.domain.vo.PayApplicationVO;
import com.zanxiang.mybatis.entity.PayApplication;

import java.util.List;
import java.util.Map;

/**
 * 游戏应用表 服务类接口
 *
 * @author xufeng
 * @date 2022-06-20 15:16
 */
public interface IPayApplicationService extends IService<PayApplication> {

    /**
     * 支付应用程序地图
     *
     * @return {@link Map}<{@link Long}, {@link PayApplicationDTO}>
     */
    Map<Long, PayApplicationDTO> payApplicationMap();

    /**
     * 支付应用情况
     *
     * @param payApplicationId   : 支付应用程序id
     * @param payApplicationType : 支付应用程序类型
     * @param appId              : 应用程序id
     * @param company            : 公司
     * @return {@link Map}<{@link Long}, {@link PayApplicationDTO}>
     */
    Map<Long, PayApplicationDTO> payApplicationCondition(Integer payApplicationId, Integer payApplicationType, String appId, String company);

    /**
     * 支付应用选择列表
     *
     * @return {@link List}<{@link PayApplicationChoiceVO}>
     */
    List<PayApplicationChoiceVO> payApplicationChoiceList();

    /**
     * 支付应用添加或者更新
     *
     * @param param : 参数
     * @return {@link Boolean}
     */
    Boolean addOrUpdate(PayApplicationAddUpdateParam param);

    /**
     * 根据主键更新状态
     *
     * @param id     : 主键id
     * @param status : 状态
     * @return {@link Boolean}
     */
    Boolean statusUpdate(Long id, Integer status);

    /**
     * 列表
     *
     * @param bo : 参数
     * @return {@link IPage}<{@link PayApplicationVO}>
     */
    IPage<PayApplicationVO> pageList(PayApplicationListParam bo);

    /**
     * 获取游戏应用二维码图片地址
     *
     * @param id : 应用id
     * @return {@link String}
     */
    String getQrCode(Long id);

    /**
     * 删除通过id
     *
     * @param id : 要删除的信息id
     * @return boolean
     */
    boolean deleteById(Long id);
}
